@@ -33,6 +33,7 @@ from calculate.update.profile import RepositoryStorageSet, DEFAULT_BRANCH
 from calculate.lib.variables.linux import VariableOsLinuxName, \
     VariableOsLinuxSubname, VariableOsLinuxVer, VariableOsLinuxShortname
 from calculate.lib.variables.env import VariableClTemplateLocation
+from calculate.update.update_info import UpdateInfo
 
 
 setLocalTranslate('cl_update3', sys.modules[__name__])
@@ -57,9 +58,9 @@ class VariableClUpdateWorld(Variable):
     metavalue = "MODE"
 
     def init(self):
-        self.help = ("'rebuild' - " + _("rebuild system packages list") +
-                     ",\n'merge' - " + _("append profile system packages list") +
-                     ",\n'update' - " + _("update system packages list"))
+        self.help = ("'rebuild' - " + _("rebuild the system packages list") +
+                     ",\n'merge' - " + _("append the profile packages list") +
+                     ",\n'update' - " + _("update the system packages list"))
         self.label = _("System packages list")
 
     def choice(self):
@@ -321,10 +322,10 @@ class VariableClUpdateEgencacheForce(Variable):
     #untrusted = True
 
     def init(self):
-        self.help = ("'force' - " + _("force the update overlays cache") +
-                     ",\n'skip' - " + _("skip the overlays cache update") +
-                     ",\n'auto' - " + _("update overlays cache if it is outdated"))
-        self.label = _("Update overlays cache")
+        self.help = ("'force' - " + _("force the update of the overlays cache") +
+                     ",\n'skip' - " + _("skip the update of the overlays cache") +
+                     ",\n'auto' - " + _("update the overlays cache if outdated"))
+        self.label = _("Update the overlays cache")
 
     def choice(self):
         return [("force", _("Force")),
@@ -563,7 +564,7 @@ class VariableClUpdateTemplatesLocate(Variable):
 
     def init(self):
         self.label = _("Templates location")
-        self.help = _("select location for templates %s") \
+        self.help = _("select the location for templates %s") \
                       %",".join(self.get())
 
     def get(self):
@@ -884,7 +885,7 @@ class VariableClUpdateProfileSystem(Variable):
                     raise VariableError("")
                 if repo_name not in list(self.Get('cl_update_profile_rep_name')):
                     raise VariableError(
-                        _("Overlay %s not specified in cl_update_rep_name")%
+                        _("Overlay %s is not specified in cl_update_rep_name")%
                             repo_name)
             except (DataVarsError,VariableError) as e:
                 if str(e):
@@ -1021,8 +1022,8 @@ class VariableClUpdateEmergelistSet(Variable):
     opt = ["-e","--emergelist"]
 
     def init(self):
-        self.label = _("Emerge like packages list")
-        self.help = _("display packages list in emerge format")
+        self.label = _("Emerge-like packages list")
+        self.help = _("display the packages list in emerge format")
 
 class VariableClUpdateKernelVersion(ReadonlyVariable):
     """
@@ -1087,3 +1088,19 @@ class VariableClUpdateCleanpkgSet(Variable):
     def init(self):
         self.label = _("Clean obsolete programs archives")
         self.help = _("clean obsolete programs archives")
+
+class VariableClUpdateOutdatedKernelPath(Variable):
+    """
+    Файл-флаг наличия устаревшего, неудаленного ядра
+    """
+    value = "/var/lib/calculate/calculate-update/outdated_kernel"
+
+class VariableClUpdateOutdatedKernelSet(ReadonlyVariable):
+    """
+    Есть наличие устаревшего ядра
+    """
+    type = "bool"
+
+    def get(self):
+        ui = UpdateInfo(self.parent)
+        return "on" if ui.outdated_kernel else "off"
